@@ -445,7 +445,7 @@ tech_rep_dot_plot <- function(hrest, score_col, group_col, tech_rep_col){
 #' @export
 #' @return ggplot object
 #' @importFrom stats quantile
-#' @importFrom ggplot2 stat
+#' @importFrom ggplot2 after_stat
 plot.hrest <- function(x, ...,  which = "rank_simulation"){
   hrest <- x
   group_col <- names(hrest$group_n)[ names(hrest$group_n) != "n" ][[1]]
@@ -471,7 +471,7 @@ plot.hrest <- function(x, ...,  which = "rank_simulation"){
 
   b <- hrest$bootstraps %>%
     ggplot2::ggplot() + ggplot2::aes(mean, !!group_col,
-                                     fill = factor(stat(quantile))) +
+                                     fill = factor(after_stat(quantile))) +
     ggplot2::xlim(min(hrest$ranked_data$rank), max(hrest$ranked_data$rank)) +
     ggridges::stat_density_ridges(geom = "density_ridges_gradient",
                                  calc_ecdf = TRUE,
